@@ -24,6 +24,40 @@
 
 /* Fortran interface descriptions: */
 
+/* ACM 526, soon to be removed */
+static R_NativePrimitiveArgType idbvip_t[13] = {
+  INTSXP,  /* MD,   */
+  INTSXP,  /* NCP,  */
+  INTSXP,  /* NDP,  */
+  REALSXP, /* XD,   */
+  REALSXP, /* YD,   */
+  REALSXP, /* ZD,   */
+  INTSXP,  /* NIP,  */
+  REALSXP, /* XI,   */
+  REALSXP, /* YI,   */
+  REALSXP, /* ZI,   */
+  INTSXP,  /* IWK,  */
+  REALSXP, /* WK,   */
+  LGLSXP   /* MISSI */
+};
+
+static R_NativePrimitiveArgType idsfft_t[14] = {
+  INTSXP,  /* MD,   */
+  INTSXP,  /* NCP,  */
+  INTSXP,  /* NDP,  */
+  REALSXP, /* XD,   */
+  REALSXP, /* YD,   */
+  REALSXP, /* ZD,   */
+  INTSXP,  /* NXI,  */
+  INTSXP,  /* NYI,  */
+  REALSXP, /* XI,   */
+  REALSXP, /* YI,   */
+  REALSXP, /* ZI,   */
+  INTSXP,  /* IWK,  */
+  REALSXP, /* WK,   */
+  LGLSXP   /* MISSI */
+};
+
 /* ACM 760: */
 static R_NativePrimitiveArgType rgbi3p_t[12] = {
   INTSXP,  /* MD,     */
@@ -120,6 +154,8 @@ static R_NativePrimitiveArgType biliip_t[9] = {
 
 
 static R_FortranMethodDef fortranMethods[] = {
+  {"idbvip", (DL_FUNC) &F77_SUB(idbvip), 13, idbvip_t}, /* interpp.old, scheduled for removal */
+  {"idsfft", (DL_FUNC) &F77_SUB(idsfft), 14, idsfft_t}, /* interp.old, scheduled for removal  */
   {"sdbi3p", (DL_FUNC) &F77_SUB(sdbi3p), 17, sdbi3p_t}, /* interpp     */
   {"sdsf3p", (DL_FUNC) &F77_SUB(sdsf3p), 18, sdsf3p_t}, /* interp      */
   {"uvip3p", (DL_FUNC) &F77_SUB(uvip3p), 8,  uvip3p_t}, /* aspline     */
